@@ -17,75 +17,6 @@
 
 from enum import Enum, auto
 
-class Key(Enum):
-	NULL = auto()
-	CANCEL = auto()
-	HELP = auto()
-	BACKSPACE = auto()
-	BACK_SPACE = auto()
-	TAB = auto()
-	CLEAR = auto()
-	RETURN = auto()
-	ENTER = auto()
-	SHIFT = auto()
-	LEFT_SHIFT = auto()
-	CONTROL = auto()
-	LEFT_CONTROL = auto()
-	ALT = auto()
-	LEFT_ALT = auto()
-	PAUSE = auto()
-	ESCAPE = auto()
-	SPACE = auto()
-	PAGE_UP = auto()
-	PAGE_DOWN = auto()
-	END = auto()
-	HOME = auto()
-	LEFT = auto()
-	ARROW_LEFT = auto()
-	UP = auto()
-	ARROW_UP = auto()
-	RIGHT = auto()
-	ARROW_RIGHT = auto()
-	DOWN = auto()
-	ARROW_DOWN = auto()
-	INSERT = auto()
-	DELETE = auto()
-	SEMICOLON = auto()
-	EQUALS = auto()
-
-	NUMPAD0 = auto()
-	NUMPAD1 = auto()
-	NUMPAD2 = auto()
-	NUMPAD3 = auto()
-	NUMPAD4 = auto()
-	NUMPAD5 = auto()
-	NUMPAD6 = auto()
-	NUMPAD7 = auto()
-	NUMPAD8 = auto()
-	NUMPAD9 = auto()
-	MULTIPLY = auto()
-	ADD = auto()
-	SEPARATOR = auto()
-	SUBTRACT = auto()
-	DECIMAL = auto()
-	DIVIDE = auto()
-
-	F1 = auto()
-	F2 = auto()
-	F3 = auto()
-	F4 = auto()
-	F5 = auto()
-	F6 = auto()
-	F7 = auto()
-	F8 = auto()
-	F9 = auto()
-	F10 = auto()
-	F11 = auto()
-	F12 = auto()
-
-	META = auto()
-	COMMAND = auto()
-
 class ModifierKey(Enum):
     CTRL = auto()
     CMD = auto()
